ConfirmationResult class

A result from a phone number sign-in, link, or reauthenticate call.

This class is only usable on web based platforms.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verificationId → String
The phone number authentication operation's verification ID.
no setter

Methods

confirm(String verificationCode) → Future<UserCredential>
Finishes a phone number sign-in, link, or reauthentication, given the code that was sent to the user's mobile device.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited