User class

A user account.

Properties

displayName → String?
The users display name.
no setter
email → String?
The users email address.
no setter
emailVerified → bool
Returns whether the users email address has been verified.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isAnonymous → bool
Returns whether the user is a anonymous.
no setter
metadata → UserMetadata
Returns additional metadata about the user, such as their creation time.
no setter
multiFactor → MultiFactor
no setter
phoneNumber → String?
Returns the users phone number.
no setter
photoURL → String?
Returns a photo URL for the user.
no setter
providerData → List<UserInfo>
Returns a list of user information for each linked provider.
no setter
refreshToken → String?
Returns a JWT refresh token for the user.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tenantId → String?
The current user's tenant ID.
no setter
uid → String
The user's unique ID.
no setter

Methods

delete() → Future<void>
Deletes and signs out the user.
getIdToken([bool forceRefresh = false]) → Future<String?>
Returns a JSON Web Token (JWT) used to identify the user to a Firebase service.
getIdTokenResult([bool forceRefresh = false]) → Future<IdTokenResult>
Returns a IdTokenResult containing the users JSON Web Token (JWT) and other metadata.
linkWithCredential(AuthCredential credential) → Future<UserCredential>
Links the user account with the given credentials.
linkWithPhoneNumber(String phoneNumber, [RecaptchaVerifier? verifier]) → Future<ConfirmationResult>
Links the user account with the given phone number.
linkWithPopup(AuthProvider provider) → Future<UserCredential>
Links the user account with the given provider.
linkWithProvider(AuthProvider provider) → Future<UserCredential>
Links with an AuthProvider using native authentication flow. On web, you should use linkWithPopup or linkWithRedirect instead.
linkWithRedirect(AuthProvider provider) → Future<void>
Links the user account with the given provider.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reauthenticateWithCredential(AuthCredential credential) → Future<UserCredential>
Re-authenticates a user using a fresh credential.
reauthenticateWithPopup(AuthProvider provider) → Future<UserCredential>
Re-authenticates a user using a popup on Web.
reauthenticateWithProvider(AuthProvider provider) → Future<UserCredential>
Re-authenticates a user using a Provider.
reauthenticateWithRedirect(AuthProvider provider) → Future<void>
Re-authenticates a user using a redirection on Web.
reload() → Future<void>
Refreshes the current user, if signed in.
sendEmailVerification([ActionCodeSettings? actionCodeSettings]) → Future<void>
Sends a verification email to a user.
toString() → String
A string representation of this object.
override
Unlinks a provider from a user account.
updateDisplayName(String? displayName) → Future<void>
Update the user name.
updateEmail(String newEmail) → Future<void>
Updates the user's email address.
updatePassword(String newPassword) → Future<void>
Updates the user's password.
updatePhoneNumber(PhoneAuthCredential phoneCredential) → Future<void>
Updates the user's phone number.
updatePhotoURL(String? photoURL) → Future<void>
Update the user's profile picture.
updateProfile({String? displayName, String? photoURL}) → Future<void>
Updates a user's profile data.
verifyBeforeUpdateEmail(String newEmail, [ActionCodeSettings? actionCodeSettings]) → Future<void>
Sends a verification email to a new email address. The user's email will be updated to the new one after being verified.

Operators

operator ==(Object other) → bool
The equality operator.
inherited